<?php
/**
 * CSS Reset and default styling
 */
drupal_add_css(drupal_get_path('theme', 'layoutstudio') . '/css/defaults.css', array('weight' => CSS_THEME, 'type' => 'file'));

function layoutstudio_preprocess_html(&$variables) {  

  // Set up layout variable.
  $variables['layout'] = 'no-secondary-and-tertiary';
  if (!empty($variables['page']['secondary'])) {
    $variables['layout'] = 'no-tertiary';
  }
  if (!empty($variables['page']['tertiary'])) {
    $variables['layout'] = ($variables['layout'] == 'no-tertiary') ? 'regions-all' : 'no-secondary';
  }
  $variables['preface_class'] = 'no-preface';
  if (!empty($variables['page']['preface'])) {
    $variables['preface_class'] = 'no-preface';
  }
  $variables['postscript_class'] = 'no-postscript';
  if (!empty($variables['page']['postscript'])) {
    $variables['postscript_class'] = 'no-postscript';
  }

  // Compile an array of classes that are going to be applied to the body element.
  // This allows advanced theming based on context (home page, node of certain type, etc.).
  // Random body class
  $random = theme_get_setting('layoutstudio_random_class');
  if ($random > 1){
    $variables['classes_array'][] = 'random-'.rand(1, $random);
  }
  // Current active menu item
 	$variables['classes_array'][] = 'menu-item-'. drupal_clean_css_identifier(drupal_strtolower(menu_get_active_title()));
  // Add information regarding the secondary & tertiary.
  if ($variables['layout'] == 'regions-all') {
    $variables['classes_array'][] = 'regions-all';
  }
  elseif ($variables['layout'] == 'no-secondary-and-tertiary') {
    $variables['classes_array'][] = 'no-secondary-and-tertiary';
  }
  else {
    $variables['classes_array'][] = $variables['layout'];
  }
  $variables['classes_array'][] = $variables['preface_class'];
  $variables['classes_array'][] = $variables['postscript_class'];

  if (!$variables['is_front']) {
		// Add unique classes for each page and website section
		$path = drupal_get_path_alias($_GET['q']);
    if (strpos($path, '/') !== FALSE) {
		  list($section, $sub_section) = explode('/', $path, 3);
    }
    else {
      $section = $path;
      $sub_section = '';
    }
		$variables['classes_array'][] = 'section-'. $section;
		$variables['classes_array'][] = 'sub-section-'. ($sub_section ? $sub_section : 'none');
		if (arg(0) == 'node') {
			if (arg(1) == 'add') {
				if ($section == 'node') {
					array_pop($variables['classes_array']); // Remove 'section-node'
					array_pop($variables['classes_array']); // Remove 'section-node'
				}
				$variables['classes_array'][] = 'section-node-add'; // Add 'section-node-add'
			}
			elseif (is_numeric(arg(1)) && (arg(2) == 'edit' || arg(2) == 'delete')) {
				if ($section == 'node') {
					array_pop($variables['classes_array']); // Remove 'section-node'
					array_pop($variables['classes_array']); // Remove 'section-node'
				}
				$variables['classes_array'][] = 'section-node-'. arg(2); // Add 'section-node-edit' or 'section-node-delete'
			}
		}
	}

  // Add classes based on the role(s) of the current user
  global $user;
  foreach ($user->roles as $role) {
    $variables['classes_array'][] = "role-".drupal_clean_css_identifier($role);
  }
  
  //Create Skip to Navigation and Content links
  $variables['skip_to_links'] = '';
  if (isset($variables['page']['navigation']) OR theme_get_setting('toggle_main_menu') OR theme_get_setting('toggle_secondary_menu')) {
    $skip_to_content ='<span class="skip-to-content"><a href="#content-area" title="Go to site content">content</a></span>';
    $skip_to_nav = ' &ndash; <span class="skip-to-nav"><a href="#nav" title="Go to site navigation">navigation</a></span>';
    $variables['skip_to_links'] = '<p class="skip-to-links">Skip to: ' . $skip_to_content . $skip_to_nav . '</p>';
  }
}

//Setting classes for body element
function layoutstudio_preprocess_page(&$variables) {

	// Set up layout variable.
  $variables['layout'] = 'no-secondary-and-tertiary';
  if (!empty($variables['page']['secondary'])) {
    $variables['layout'] = 'no-tertiary';
  }
  if (!empty($variables['page']['tertiary'])) {
    $variables['layout'] = ($variables['layout'] == 'no-tertiary') ? 'regions-all' : 'no-secondary';
  }
  $variables['preface_classes_array'] = 'no-preface';
  if (!empty($variables['page']['preface'])) {
    $variables['preface_classes_array'] = 'no-preface';
  }
  $variables['postscript_classes_array'] = 'no-postscript';
  if (!empty($variables['page']['postscript'])) {
    $variables['postscript_classes_array'] = 'no-postscript';
  }

  // Add layout specific CSS to the page.
  layoutstudio_add_layout_css($variables);

	 //Hide or show breadcrumb option
  $variables['breadcrumb_display'] = theme_get_setting('layoutstudio_breadcrumb_display');
  
}

/**
 * Implements hook_preprocess_maintenance_page().
 */
function layoutstudio_preprocess_maintenance_page(&$variables) {
  if (!$variables['db_is_active']) {
    $variables['site_name'] = '';
  }
  drupal_add_css(drupal_get_path('theme', 'layoutstudio') . '/css/maintenance-page.css');
}

//Setting classes for nodes
function layoutstudio_preprocess_node(&$variables) {
  global $user;

	// Compile an array of classes that are going to be applied to the node div.
	if ($variables['node']->uid && $variables['node']->uid == $user->uid) {
		// Node is authored by current user
		$variables['classes_array'][] = 'user-me';
	}
	//Add node's user id
	$variables['classes_array'][] = 'user-' . $variables['node']->uid;

	if ($variables['teaser']) {
		// Node is displayed as teaser
    $variables['classes_array'][] = 'node-'. $variables['node']->type.'-teaser';
	}
	else {
		$variables['classes_array'][] = 'node-full';
    $variables['classes_array'][] = 'node-'. $variables['node']->type.'-full';
	}
	//odd/even class for node listings
	$variables['classes_array'][] = $variables['zebra'];
	//node count for node listings
	$variables['classes_array'][] = 'count-' . $variables['id'];
	//Add clear fix class
	$variables['classes_array'][] = 'clearfix';

  // Add classes based on the role(s) of the node author
  $account = user_load($variables['node']->uid);
  foreach ($account->roles as $role) {
    $variables['classes_array'][] = "role-".drupal_clean_css_identifier($role);
  }
}

/*
function layoutstudio_preprocess_region(&$variables) {
}
*/

//Setting classes for blocks
function layoutstudio_preprocess_block(&$variables) {
  // Random block class
  $random = theme_get_setting('layoutstudio_random_class');
  if ($random > 1){
    $variables['classes_array'][] = 'random-'.rand(1, $random);
  }
  $variables['classes_array'][] = $variables['block_zebra'];
  $variables['classes_array'][] = 'region-count-'. $variables['block_id'];
	//Add clear fix class
	$variables['classes_array'][] = 'clearfix';
	$variables['title_attributes_array']['class'][] = 'block-title';
}

// Setting classes for comments
function layoutstudio_preprocess_comment(&$variables) {
  static $comment_counter = array();

  if (!isset($comment_counter[$variables['node']->nid])) {
    $comment_counter[$variables['node']->nid] = 1;
  }
  $variables['classes_array'][] = ($comment_counter[$variables['node']->nid] % 2) ? 'odd' : 'even';
  $variables['classes_array'][] = 'comment-'.$variables['comment']->cid;
  $comment_counter[$variables['node']->nid]++;

  // Add classes based on the role(s) of the comment author
  $account = user_load($variables['comment']->uid);
  foreach ($account->roles as $role) {
    $variables['classes_array'][] = "role-".drupal_clean_css_identifier($role);
  }
}

function layoutstudio_add_layout_css(&$variables) {
  // Add dimensions and other layout specific styles.
  $layout = layoutstudio_theme_get_setting('layoutstudio_layout');
  $page_width = layoutstudio_theme_get_setting('layoutstudio_page_width');
  $secondary_width = layoutstudio_theme_get_setting('layoutstudio_secondary_width');
  $tertiary_width = layoutstudio_theme_get_setting('layoutstudio_tertiary_width');
  $primary_width = $page_width - ($secondary_width + $tertiary_width);
  $viewport_regions = layoutstudio_theme_get_setting('layoutstudio_viewport_regions');
  $data = '';
  
  if ($layout != 'layout9') {
  
		//Determine if any regions need to be full browser width
    if (is_array($viewport_regions)) {
      if (count(array_count_values($viewport_regions)) == 1) {
        $data .= "#page { width: " . $page_width ."px; margin: 0px auto; }\r\n";
      }
      else {
        foreach($viewport_regions as $k => $v) {
          if($v) { // Full width regions
            $data .= "#" . $k . " .inside { margin: 0px auto; width: " . $page_width ."px; } #content .inside .inside { margin: 0; width: auto; }\r\n";
            $data .= "#breadcrumb { width: " . $page_width ."px; margin: 0px auto; }\r\n";
          }
          if (!$v) { //Not full width regions
            $data .= "#" . $k . " { margin: 0px auto; width: " . $page_width ."px; }\r\n";
          }
        }
      }
    }
		
		//Give regions their dimensions
		$data .= '#primary, #secondary, #tertiary { display: inline; float: left; }';
		$data .= '#primary { width: ' . $primary_width . 'px;}';
		$data .= '.no-secondary-and-tertiary #primary { display: block; float: none; width: auto; position: static; }';
		$data .= '#secondary { width: ' . $secondary_width . 'px;}'; 
		$data .= '#tertiary { width: ' . $tertiary_width . 'px;}';
		
		// Create Layouts
		switch($layout) {
			
			case 'layout1':
				// secondary on the left, primary in the middle, tertiary on the right
				$data .= '#primary, #secondary { position: relative; }';
				$data .= "#primary { left: " . $secondary_width . "px; }\r\n";
				$data .= "#secondary { left: -" . $primary_width . "px; }\r\n";
				$data .= ".no-secondary #primary { position: static; width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #secondary { left: -" . ($primary_width + $tertiary_width) . "px; }\r\n";
			break;
			
			case 'layout2':
				// tertiary on the left, primary in the middle, secondary on the right
				$data .= '#primary, #secondary, #tertiary { position: relative; }';
				$data .= "#primary { left: " . $tertiary_width . "px; }\r\n";
				$data .= "#secondary { left: " . $tertiary_width . "px; }\r\n";
				$data .= "#tertiary { left: -" . ($page_width - $tertiary_width) . "px; }\r\n";
				$data .= ".no-secondary #primary { width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { position: static; width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #secondary { position: static; }\r\n";
			break;
			
			case 'layout3':
				$data .= ".no-secondary #primary { width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
			break;
			
			case 'layout4':
				// primary left, sidebar second in the middle, and sidebar first on the right
				$data .= '#secondary, #tertiary { position: relative; }';
				$data .= "#secondary { left: " . $tertiary_width . "px; }\r\n";
				$data .= "#tertiary { left: -" . $secondary_width . "px; }\r\n";
				$data .= ".no-secondary #primary { width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
				$data .= ".no-secondary #tertiary, .no-tertiary #secondary { position: static; }\r\n";
			break;
			
			case 'layout5':
				// secondary on the left, tertiary in the middle, and primary on the right
				$data .= '#primary, #secondary, #tertiary { position: relative; }';
				$data .= "#primary { left: " . ($secondary_width + $tertiary_width) . "px; }\r\n";
				$data .= "#secondary { left: -" . $primary_width . "px; }\r\n";
				$data .= "#tertiary { left: -" . ($page_width - $tertiary_width - $secondary_width) . "px; }\r\n";
				$data .= ".no-secondary #primary { left: " . $tertiary_width . "px; width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-secondary #tertiary { left: -" . ($page_width - $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { left: " . $secondary_width . "px; width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #secondary { left: -" . ($primary_width + $tertiary_width) . "px; }\r\n";
			break;
			
			case 'layout6':
				// tertiary on the left, secondary in the middle, primary on the right
				$data .= '#primary, #secondary, #tertiary { position: relative; }';
				$data .= "#primary { left: " . ($secondary_width + $tertiary_width) . "px; }\r\n";
				$data .= "#secondary { left: -" . ($primary_width - $tertiary_width) . "px; }\r\n";
				$data .= "#tertiary { left: -" . ($page_width - $tertiary_width) . "px; }\r\n";
				$data .= ".no-secondary #primary { left: " . $tertiary_width . "px; width: " . ($primary_width + $secondary_width) . "px; }\r\n";
				$data .= ".no-secondary #tertiary { left: -" . ($page_width - $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #primary { left: " . $secondary_width . "px; width: " . ($primary_width + $tertiary_width) . "px; }\r\n";
				$data .= ".no-tertiary #secondary { left: -" . ($primary_width + $tertiary_width) . "px; }\r\n";
			break;
			
			case 'layout7':
				// primary on top, secondary and 
				$data .= "#primary { display: block; float:none; width: auto;  }\r\n";
				$data .= "#secondary { width: " . $secondary_width . "px; }\r\n";
				$data .= "#tertiary { width: " . ($page_width - $secondary_width) . "px; }\r\n";
				$data .= ".no-secondary #tertiary, .no-tertiary #secondary { width: auto; }\r\n";
			break;
			
			case 'layout8':
				// stacked full widths.. do I really need to add the widhts here?
				$data .= "#primary, #secondary, #tertiary { display: block; float:none; width: auto; }\r\n";
			break;
		}
	
		drupal_add_css('@media screen, projection {' . $data . '}', array('type' => 'inline'));

  }  
  
}

/**
 * Helper function that loads a theme setting. Using this function allows for theme settings to be overridden on specific
 * pages via the LayoutStudio Extras module.
 */
function layoutstudio_theme_get_setting($setting_name) {
  if (module_exists('layoutstudio_extras')) {
    if (function_exists('layoutstudio_extras_theme_get_setting')) {
      // Load a theme setting via the LayoutStudio Extras companion module, which will determine if a default setting has
      // been overridden via an adjustment for the current page.
      return layoutstudio_extras_theme_get_setting($setting_name);
    }
  }

  // Load the setting the normal way if LayoutStudio Extras is not installed.
  return theme_get_setting($setting_name);
}