<?php
/**
 * @file
 * layoutstudio's theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template normally located in the
 * modules/system folder.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $hide_site_name: TRUE if the site name has been toggled off on the theme
 *   settings page. If hidden, the "element-invisible" class is added to make
 *   the site name visually hidden, but still accessible.
 * - $hide_site_slogan: TRUE if the site slogan has been toggled off on the
 *   theme settings page. If hidden, the "element-invisible" class is added to
 *   make the site slogan visually hidden, but still accessible.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - regions[header]: Items for the header region.
 * - regions[preface]: Middle preface region
 * - regions[highlighted]: Highlight region as recommended for Drupal 7 themes
 * - regions[help]: Help region as recommended for Drupal 7 themes
 * - regions[content]: Primary/main content area
 * - regions[left]: Middle secondary region
 * - regions[right]: Middle tertiary region
 * - regions[postscript]: Middle postscript region
 * - regions[navigation]: Region for navigation/menu blocks
 * - regions[footer]: Site footer
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 * @see layoutstudio_process_page()
 */
?>
<div id="header" class="clearfix">
	<div class="inside">
		
		<?php if ($logo): ?>
			<?php if ($is_front): ?>
        <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
			<?php else: ?>
	      <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="logo">
	        <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
	      </a>
			<?php endif; ?>			
    <?php endif; ?>

		<?php if ($site_name): ?>
			<p class="site-name">
				<?php if ($is_front): ?>
					<?php print $site_name; ?>	
				<?php else: ?>
					<a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home">
						<?php print $site_name; ?>
					</a>
				<?php endif; ?>			
			</p>
		<?php endif; ?>
		
		<?php if ($site_slogan): ?>
			<p class="site-slogan"><?php print $site_slogan; ?></p>
		<?php endif; ?>

		<?php print render($page['header']); ?>
	
	</div><!-- CLASS inside -->
</div><!-- ID header -->

<?php if ($breadcrumb && $breadcrumb_display): ?>
	<div id="breadcrumb">
		<div class="inside">
			<?php print $breadcrumb;?>
		</div><!-- CLASS inside -->
	</div><!-- ID breadcrumb -->
<?php endif; ?>

<?php print render($page['preface']); ?>

<div id="content">
	<div class="inside" class="clearfix">
	
		<?php print render($page['highlighted']); ?>
		<?php print render($page['help']); ?>
		<?php print $messages; ?>

		<div id="primary">

			<a id="content-area"></a>
						          			
      <?php print render($title_prefix); ?>
      <?php if ($title): ?>
        <h1 class="title" id="page-title">
          <?php print $title; ?>
        </h1>
      <?php endif; ?>
      <?php print render($title_suffix); ?>

      <?php if ($tabs): ?>
        <div class="tabs">
          <?php print render($tabs); ?>
        </div>
      <?php endif; ?>
      
      <?php if ($action_links): ?>
        <ul class="action-links">
          <?php print render($action_links); ?>
        </ul>
      <?php endif; ?>

      <?php print render($page['content']); ?>

      <?php print $feed_icons; ?>			

		</div><!-- ID primary -->

  	<?php print render($page['secondary']); ?>

  	<?php print render($page['tertiary']); ?>

	</div><!-- CLASS inside -->
</div><!-- ID content -->
	
<?php print render($page['postscript']); ?>
	
<?php if ($page['navigation'] OR $main_menu OR $secondary_menu): ?>
	<div id="navigation">
		<div class="inside">
			<a id="nav"></a>
			
			<?php if ($main_menu): ?>
	      <div id="main-menu" class="navigation">
	        <?php print theme('links__system_main_menu', array(
	          'links' => $main_menu,
	          'attributes' => array(
	            'id' => 'main-menu-links',
	            'class' => array('links', 'clearfix'),
	          ),
	          'heading' => array(
	            'text' => t('Main menu'),
	            'level' => 'h2',
	            'class' => array('element-invisible'),
	          ),
	        )); ?>
	      </div> <!-- ID main-menu -->
	    <?php endif; ?>
	
	    <?php if ($secondary_menu): ?>
	      <div id="secondary-menu" class="navigation">
	        <?php print theme('links__system_secondary_menu', array(
	          'links' => $secondary_menu,
	          'attributes' => array(
	            'id' => 'secondary-menu-links',
	            'class' => array('links', 'inline', 'clearfix'),
	          ),
	          'heading' => array(
	            'text' => t('Secondary menu'),
	            'level' => 'h2',
	            'class' => array('element-invisible'),
	          ),
	        )); ?>
	      </div> <!-- ID secondary-menu -->
	    <?php endif; ?>
	
			<?php print render($page['navigation']); ?>

		</div><!-- CLASS inside -->
	</div><!-- ID navigation -->
<?php endif; ?>

<?php print render($page['footer']); ?>